TxKeys

Trait TxKeys 

pub trait TxKeys<K, IndexedKeys, S = DefaultBuildHasher>
where K: Hash + Eq, S: BuildHasher,
{ // Required method fn into_indexed( self, shard_count: ShardCount, indexer: &Indexer<S>, ) -> IndexedKeys; }
Raw keys that can be hashed into indexed keys.

Required Methods

fn into_indexed( self, shard_count: ShardCount, indexer: &Indexer<S>, ) -> IndexedKeys

Converts raw keys to indexed keys by computing hashes and shard indices.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors