pub trait TxKeys<K, IndexedKeys, S = DefaultBuildHasher>{
// Required method
fn into_indexed(
self,
shard_count: ShardCount,
indexer: &Indexer<S>,
) -> IndexedKeys;
}Expand description
Raw keys that can be hashed into indexed keys.
Required Methods
Sourcefn into_indexed(
self,
shard_count: ShardCount,
indexer: &Indexer<S>,
) -> IndexedKeys
fn into_indexed( self, shard_count: ShardCount, indexer: &Indexer<S>, ) -> IndexedKeys
Converts raw keys to indexed keys by computing hashes and shard indices.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".